TextStyleEditor class

Text style editor A flutter widget that edit text style and text alignment

You can pass your text style or alignment to the widget and then get the edited text style

Inheritance

Constructors

TextStyleEditor({Key? key, List<Color>? paletteColors, EditorToolbarAction initialTool = EditorToolbarAction.fontFamilyTool, dynamic onTextStyleEdited(TextStyle)?, dynamic onTextAlignEdited(TextAlign)?, dynamic onCapsLockToggle(bool)?, dynamic onToolbarActionChanged(EditorToolbarAction)?})
Create a TextStyleEditor widget
const

Properties

hashCode int
The hash code for this object.
no setterinherited
initialTool EditorToolbarAction
The initial editor tool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onCapsLockToggle → dynamic Function(bool)?
onCapsLockToggle will be called after caps lock has changed
final
onTextAlignEdited → dynamic Function(TextAlign)?
onTextAlignEdited will be called after textAlignment prop has changed
final
onTextStyleEdited → dynamic Function(TextStyle)?
onTextStyleEdited will be called after textStyle prop has changed
final
onToolbarActionChanged → dynamic Function(EditorToolbarAction)?
onToolbarActionChanged will be called after editor's tool has changed
final
paletteColors List<Color>?
Editor's palette colors
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _TextStyleEditorState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited