EditorInitialEvent class
- Inheritance
-
- Object
- TextEditorEvent
- EditorInitialEvent
Constructors
-
EditorInitialEvent({required TextStyle textStyle, required EditorToolbarAction initialTool, required List<
Color> paletteColors, required TextAlign textAlign})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialTool ↔ EditorToolbarAction
-
getter/setter pair
-
paletteColors
↔ List<
Color> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textAlign ↔ TextAlign
-
getter/setter pair
- textStyle ↔ TextStyle
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited